<?php
namespace Affilivice\Design\Customizer;

if (!defined('ABSPATH')) {
	exit('Not allowed to access pages directly.');
}

class General_Customizer extends Abstract_Customizer
{
	/**
	 * @inheritdoc
	 * @since 0.6
	 */
	public function init()
	{
		$section = 'affvc-general';

		$sections[] = array(
			'id'       => $section,
			'title'    => __('General', 'affilivice'),
			'priority' => '10',
		);

		$options['affvc-general-background-color-top'] = array(
			'id'        => 'affvc-general-background-color-top',
			'label'     => __('Background Color (Top)', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#ebebeb',
			'transport' => 'postMessage',
		);

		$options['affvc-general-background-color-bottom'] = array(
			'id'        => 'affvc-general-background-color-bottom',
			'label'     => __('Background Color (Bottom)', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#ebebeb',
			'transport' => 'postMessage',
		);

		$options['affvc-general-background-image'] = array(
			'id'        => 'affvc-general-background-image',
			'label'     => __('Background Image', 'affilivice'),
			'section'   => $section,
			'type'      => 'upload',
			'default'   => '',
			'transport' => 'postMessage',
		);

		$options['affvc-general-background-repeat'] = array(
			'id'        => 'affvc-general-background-repeat',
			'label'     => __('Background Repeat', 'affilivice'),
			'section'   => $section,
			'type'      => 'select',
			'choices'   => array(
				'no-repeat' => __('None', 'affilivice'),
				'repeat'    => __('Repeat', 'affilivice'),
				'repeat-x'  => __('Repeat X', 'affilivice'),
				'repeat-y'  => __('Repeat Y', 'affilivice'),
			),
			'default'   => 'no-repeat',
			'transport' => 'postMessage',
		);

		$options['affvc-general-background-attachment'] = array(
			'id'        => 'affvc-general-background-attachment',
			'label'     => __('Background Attachment', 'affilivice'),
			'section'   => $section,
			'type'      => 'select',
			'choices'   => array(
                'fixed'   => __('Fixed', 'affilivice'),
                'scroll'  => __('Scroll', 'affilivice'),
				'local'   => __('Local', 'affilivice'),
			),
			'default'   => 'fixed',
			'transport' => 'postMessage',
		);

		$options['affvc-general-background-size'] = array(
			'id'        => 'affvc-general-background-size',
			'label'     => __('Background Size', 'affilivice'),
			'section'   => $section,
			'type'      => 'select',
			'choices'   => array(
				'auto'    => __('None', 'affilivice'),
				'custom'  => __('Custom', 'affilivice'),
				'contain' => __('Contain', 'affilivice'),
				'cover'   => __('Cover', 'affilivice'),
			),
			'default'   => 'auto',
			'transport' => 'postMessage',
		);

		$options['affvc-general-background-width'] = array(
			'id'        => 'affvc-general-background-width',
			'label'     => __('Background Width', 'affilivice'),
			'section'   => $section,
			'type'      => 'text',
			'transport' => 'postMessage',
		);

		$options['affvc-general-background-height'] = array(
			'id'        => 'affvc-general-background-height',
			'label'     => __('Background Height', 'affilivice'),
			'section'   => $section,
			'type'      => 'text',
			'transport' => 'postMessage',
		);

		$options['sections'] = $sections;

		return $options;
	}

	/**
	 * @inheritdoc
	 * @since 0.6
	 */
	public function render()
	{
		$this->render_selectors(
			'affvc-general-background-color-top',
			'affvc-general-background-color-bottom',
			function ($mod1, $mod2) {
				$top    = sanitize_hex_color($mod1);
				$bottom = sanitize_hex_color($mod2);

				if($top === $bottom) {
					return array(
						'selectors'    => array(
							'body',
						),
						'declarations' => array(
							'background-color' => $bottom,
						)
					);
				}

				// The spaces are necessary to avoid duplicated keys
				return array(
					'selectors'    => array(
						'body',
					),
					'declarations' => array(
						'background-color' => $bottom,
						'background'       => "-webkit-gradient(linear, 0% 0%, 0% 100%, from($top), to($bottom))",
						'background '      => "-webkit-linear-gradient(top, $top, $bottom)",
						'background  '     => "-moz-linear-gradient(top, $top, $bottom)",
						'background   '    => "-o-linear-gradient(top, $top, $bottom)",
						'background    '   => "linear-gradient($top, $bottom)",
					)
				);
			}
		);

		$this->render_selectors('affvc-general-background-image', function ($mod) {
			$url = esc_url($mod);
			if(empty($url)) {
				return null;
			}

			return array(
				'selectors'    => array(
					'body',
				),
				'declarations' => array(
					'background-image' => 'url(' . $url . ')'
				)
			);
		});

		$this->render_selectors('affvc-general-background-repeat', function ($mod) {
			if(empty($mod)) {
				return null;
			}

			return array(
				'selectors'    => array(
					'body',
				),
				'declarations' => array(
					'background-repeat' => $mod
				)
			);
		});

		$this->render_selectors('affvc-general-background-attachment', function ($mod) {
			if(empty($mod)) {
				return null;
			}

			return array(
				'selectors'    => array(
					'body',
				),
				'declarations' => array(
					'background-attachment' => $mod
				)
			);
		});

		$this->render_selectors(
			'affvc-general-background-size',
			'affvc-general-background-width',
			'affvc-general-background-height',
			function ($size, $width, $height) {
				if(empty($size)) {
					return null;
				}

				if ($size === 'custom') {
					return array(
						'selectors'    => array(
							'body',
						),
						'declarations' => array(
							'background-size' => $width . ' ' . $height,
						)
					);
				}

				return array(
					'selectors'    => array(
						'body',
					),
					'declarations' => array(
						'background-size' => $size
					)
				);
			}
		);
	}
}
