<?php
namespace Affilivice\Design\Customizer;

if (!defined('ABSPATH')) {
	exit('Not allowed to access pages directly.');
}

class Header_Customizer extends Abstract_Customizer
{
	/**
	 * @inheritdoc
	 * @since 0.6
	 */
	public function init()
	{
        $font_choices = array(
            'serif'          => 'Serif',
            'sans-serif'     => 'Sans Serif',
            'helvetica'      => 'Helvetica',
            'helvetica neue' => 'Helvetica Neue',
            'monospace'      => 'Monospaced',
        );

		$panel = 'affvc-header';

		$panels[] = array(
			'id'       => $panel,
			'title'    => __('Header', 'affilivice'),
			'priority' => '30'
		);

        $section = 'affvc-header-banner';

        $sections[] = array(
            'id'       => $section,
            'title'    => __('Banner', 'affilivice'),
            'priority' => '10',
            'panel'    => $panel
        );

		$options['affvc-header-banner-background-color-top'] = array(
			'id'        => 'affvc-header-banner-background-color-top',
			'label'     => __('Background Color (Top)', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#fff',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-background-color-bottom'] = array(
			'id'        => 'affvc-header-banner-background-color-bottom',
			'label'     => __('Background Color (Bottom)', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#fff',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-background-image'] = array(
			'id'        => 'affvc-header-banner-background-image',
			'label'     => __('Background Image', 'affilivice'),
			'section'   => $section,
			'type'      => 'upload',
			'default'   => '',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-background-repeat'] = array(
			'id'        => 'affvc-header-banner-background-repeat',
			'label'     => __('Background Repeat', 'affilivice'),
			'section'   => $section,
			'type'      => 'select',
			'choices'   => array(
				'no-repeat' => __('None', 'affilivice'),
				'repeat'    => __('Repeat', 'affilivice'),
				'repeat-x'  => __('Repeat X', 'affilivice'),
				'repeat-y'  => __('Repeat Y', 'affilivice'),
			),
			'default'   => 'no-repeat',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-background-attachment'] = array(
			'id'        => 'affvc-header-banner-background-attachment',
			'label'     => __('Background Attachment', 'affilivice'),
			'section'   => $section,
			'type'      => 'select',
			'choices'   => array(
                'fixed'   => __('Fixed', 'affilivice'),
                'scroll'  => __('Scroll', 'affilivice'),
                'local'   => __('Local', 'affilivice'),
			),
			'default'   => 'fixed',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-background-size'] = array(
			'id'        => 'affvc-header-banner-background-size',
			'label'     => __('Background Size', 'affilivice'),
			'section'   => $section,
			'type'      => 'select',
			'choices'   => array(
				'auto'    => __('None', 'affilivice'),
				'custom'  => __('Custom', 'affilivice'),
				'contain' => __('Contain', 'affilivice'),
				'cover'   => __('Cover', 'affilivice'),
			),
			'default'   => 'auto',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-background-width'] = array(
			'id'        => 'affvc-header-banner-background-width',
			'label'     => __('Background Width', 'affilivice'),
			'section'   => $section,
			'type'      => 'text',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-background-height'] = array(
			'id'        => 'affvc-header-banner-background-height',
			'label'     => __('Background Height', 'affilivice'),
			'section'   => $section,
			'type'      => 'text',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-title-color'] = array(
			'id'        => 'affvc-header-banner-title-color',
			'label'     => __('Title Color', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#000',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-title-shadow-color'] = array(
			'id'          => 'affvc-header-banner-title-shadow-color',
			'label'       => __('Title Shadow Color', 'affilivice'),
			'section'     => $section,
            'description' => __('Leave the color empty for transparency.', 'affilivice'),
			'type'        => 'color',
			'default'     => '',
			'transport'   => 'postMessage',
		);

        $options['affvc-header-banner-title-font-family'] = array(
            'id'        => 'affvc-header-banner-title-font-family',
            'label'     => __('Title Font Family', 'affilivice'),
            'section'   => $section,
            'type'      => 'select',
            'choices'   => $font_choices,
            'default'   => 'helvetica neue',
            'transport' => 'postMessage'
        );

		$options['affvc-header-banner-tagline-color'] = array(
			'id'        => 'affvc-header-banner-tagline-color',
			'label'     => __('Tagline Color', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#555',
			'transport' => 'postMessage',
		);

		$options['affvc-header-banner-tagline-shadow-color'] = array(
			'id'          => 'affvc-header-banner-tagline-shadow-color',
			'label'       => __('Tagline Shadow Color', 'affilivice'),
			'section'     => $section,
			'description' => __('Leave the color empty for transparency.', 'affilivice'),
			'type'        => 'color',
			'default'     => '',
			'transport'   => 'postMessage',
		);

        $options['affvc-header-banner-tagline-font-family'] = array(
            'id'        => 'affvc-header-banner-tagline-font-family',
            'label'     => __('Tagline Font Family', 'affilivice'),
            'section'   => $section,
            'type'      => 'select',
            'choices'   => $font_choices,
            'default'   => 'helvetica neue',
            'transport' => 'postMessage'
        );

		$section = 'affvc-header-main-menu';

		$sections[] = array(
			'id'       => $section,
			'title'    => __('Main Menu', 'affilivice'),
			'priority' => '11',
			'panel'    => $panel
		);

        $options['affvc-header-main-menu-title'] = array(
            'id'        => 'affvc-header-main-menu-title',
            'label'     => __('Title', 'affilivice'),
            'description' => __('Only visible on mobile devices', 'affilivice'),
            'section'   => $section,
            'type'      => 'text',
            'transport' => 'postMessage',
        );

        $options['affvc-header-main-menu-background-color-top'] = array(
            'id'        => 'affvc-header-main-menu-background-color-top',
            'label'     => __('Background Color (Top)', 'affilivice'),
            'section'   => $section,
            'type'      => 'color',
            'default'   => '#f8f8f8',
            'transport' => 'postMessage',
        );

        $options['affvc-header-main-menu-background-color-bottom'] = array(
            'id'        => 'affvc-header-main-menu-background-color-bottom',
            'label'     => __('Background Color (Bottom)', 'affilivice'),
            'section'   => $section,
            'type'      => 'color',
            'default'   => '#f8f8f8',
            'transport' => 'postMessage',
        );

		$options['affvc-header-main-menu-link-color'] = array(
			'id'        => 'affvc-header-main-menu-link-color',
			'label'     => __('Link Color', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#555',
			'transport' => 'postMessage',
		);

		$options['affvc-header-main-menu-link-color-hover'] = array(
			'id'        => 'affvc-header-main-menu-link-color-hover',
			'label'     => __('Link Color (Hover)', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#000',
			'transport' => 'postMessage',
		);

		$options['affvc-header-main-menu-dropdown-background-color'] = array(
			'id'        => 'affvc-header-main-menu-dropdown-background-color',
			'label'     => __('Dropdown Background Color', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#434a54',
			'transport' => 'postMessage',
		);

		$options['affvc-header-main-menu-dropdown-item-background-color-hover'] = array(
			'id'        => 'affvc-header-main-menu-dropdown-item-background-color-hover',
			'label'     => __('Dropdown Item Background Color (Hover)', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#353a42',
			'transport' => 'postMessage',
		);

		$options['affvc-header-main-menu-dropdown-link-color'] = array(
			'id'        => 'affvc-header-main-menu-dropdown-link-color',
			'label'     => __('Dropdown Link Color', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#fff',
			'transport' => 'postMessage',
		);

		$options['affvc-header-main-menu-dropdown-link-color-hover'] = array(
			'id'        => 'affvc-header-main-menu-dropdown-link-color-hover',
			'label'     => __('Dropdown Link Color (Hover)', 'affilivice'),
			'section'   => $section,
			'type'      => 'color',
			'default'   => '#fff',
			'transport' => 'postMessage',
		);

        $options['affvc-header-main-menu-toggle-icon-color'] = array(
            'id'          => 'affvc-header-main-menu-toggle-icon-color',
            'label'       => __('Toggle Icon Color', 'affilivice'),
            'description' => __('Only visible on mobile devices', 'affilivice'),
            'section'     => $section,
            'type'        => 'color',
            'default'     => '#555555',
            'transport'   => 'postMessage',
        );

        $options['affvc-header-main-menu-toggle-icon-color-hover'] = array(
            'id'          => 'affvc-header-main-menu-toggle-icon-color-hover',
            'label'       => __('Toggle Icon Color (Hover)', 'affilivice'),
            'description' => __('Only visible on mobile devices', 'affilivice'),
            'section'     => $section,
            'type'        => 'color',
            'default'     => '#000000',
            'transport'   => 'postMessage',
        );

		$options['affvc-header-main-menu-toggle-border-color'] = array(
			'id'          => 'affvc-header-main-menu-toggle-border-color',
			'label'       => __('Toggle Border Color', 'affilivice'),
			'description' => __('Only visible on mobile devices', 'affilivice'),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#555555',
			'transport'   => 'postMessage',
		);

		$options['affvc-header-main-menu-toggle-border-color-hover'] = array(
			'id'          => 'affvc-header-main-menu-toggle-border-color-hover',
			'label'       => __('Toggle Border Color (Hover)', 'affilivice'),
			'description' => __('Only visible on mobile devices', 'affilivice'),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#000000',
			'transport'   => 'postMessage',
		);

		$options['sections'] = $sections;
		$options['panels']   = $panels;

		return $options;
	}

	/**
	 * @inheritdoc
	 * @since 0.6
	 */
	public function render()
	{
		$this->render_selectors(
			'affvc-header-banner-background-color-top',
			'affvc-header-banner-background-color-bottom',
			function ($mod1, $mod2) {
				$top    = sanitize_hex_color($mod1);
				$bottom = sanitize_hex_color($mod2);

				if ($top === $bottom) {
					return array(
						'selectors'    => array(
							'#header',
						),
						'declarations' => array(
							'background-color' => $bottom,
						)
					);
				}

				// The spaces are necessary to avoid duplicated keys
				return array(
					'selectors'    => array(
						'#header'
					),
					'declarations' => array(
						'background-color' => $bottom,
						'background'       => "-webkit-gradient(linear, 0% 0%, 0% 100%, from($top), to($bottom))",
						'background '      => "-webkit-linear-gradient(top, $top, $bottom)",
						'background  '     => "-moz-linear-gradient(top, $top, $bottom)",
						'background   '    => "-o-linear-gradient(top, $top, $bottom)",
						'background    '   => "linear-gradient($top, $bottom)",
					)
				);
			}
		);

		$this->render_selectors('affvc-header-banner-background-image', function ($mod) {
			$url = esc_url($mod);
			if(empty($url)) {
				return null;
			}

			return array(
				'selectors'    => array(
					'#header',
				),
				'declarations' => array(
					'background-image' => 'url(' . $url . ')'
				)
			);
		});

		$this->render_selectors('affvc-header-banner-background-repeat', function ($mod) {
			if(empty($mod)) {
				return null;
			}

			return array(
				'selectors'    => array(
					'#header',
				),
				'declarations' => array(
					'background-repeat' => $mod
				)
			);
		});

		$this->render_selectors('affvc-header-banner-background-attachment', function ($mod) {
			if(empty($mod)) {
				return null;
			}

			return array(
				'selectors'    => array(
					'#header',
				),
				'declarations' => array(
					'background-attachment' => $mod
				)
			);
		});

		$this->render_selectors(
			'affvc-header-banner-background-size',
			'affvc-header-banner-background-width',
			'affvc-header-banner-background-height',
			function ($size, $width, $height) {
				if(empty($size)) {
					return null;
				}

				if ($size === 'custom') {
					return array(
						'selectors'    => array(
							'#header',
						),
						'declarations' => array(
							'background-size' => $width . ' ' . $height,
						)
					);
				}

				return array(
					'selectors'    => array(
						'#header',
					),
					'declarations' => array(
						'background-size' => $size
					)
				);
			}
		);

		$this->render_selectors('affvc-header-banner-title-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#title'
				),
				'declarations' => array(
					'color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-banner-title-shadow-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			// There is no transparent color picker. The color #600099 stands for transparency
			if ($color !== '') {
				return array(
					'selectors'    => array(
						'#title'
					),
					'declarations' => array(
						'text-shadow' => '1px 1px 1px ' . $color
					)
				);
			}
		});

        $this->render_selectors('affvc-header-banner-title-font-family', function ($mod) {
            $stack = customizer_library_get_font_stack($mod);

            return array(
                'selectors'    => array(
                    '#title'
                ),
                'declarations' => array(
                    'font-family' => $stack
                )
            );
        });

		$this->render_selectors('affvc-header-banner-tagline-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#tagline'
				),
				'declarations' => array(
					'color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-banner-tagline-shadow-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			// There is no transparent color picker. The color #600099 stands for transparency
			if ($color !== '') {
				return array(
					'selectors'    => array(
						'#tagline'
					),
					'declarations' => array(
						'text-shadow' => '1px 1px 1px ' . $color
					)
				);
			}
		});

        $this->render_selectors('affvc-header-banner-tagline-font-family', function ($mod) {
            $stack = customizer_library_get_font_stack($mod);

            return array(
                'selectors'    => array(
                    '#tagline'
                ),
                'declarations' => array(
                    'font-family' => $stack
                )
            );
        });

		$this->render_selectors(
			'affvc-header-main-menu-background-color-top',
			'affvc-header-main-menu-background-color-bottom',
			function ($mod1, $mod2) {
				$top    = sanitize_hex_color($mod1);
				$bottom = sanitize_hex_color($mod2);

				// The spaces are necessary to avoid duplicated keys
				return array(
					'selectors'    => array(
						'#main-menu'
					),
					'declarations' => array(
						'background-color' => $bottom,
						'background'       => "-webkit-gradient(linear, 0% 0%, 0% 100%, from($top), to($bottom))",
						'background '      => "-webkit-linear-gradient(top, $top, $bottom)",
						'background  '     => "-moz-linear-gradient(top, $top, $bottom)",
						'background   '    => "-o-linear-gradient(top, $top, $bottom)",
						'background    '   => "linear-gradient($top, $bottom)",
					)
				);
			}
		);

		$this->render_selectors('affvc-header-main-menu-link-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .navbar-nav > .nav-item > .nav-link',
					'#main-menu .navbar-brand'
				),
				'declarations' => array(
					'color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-main-menu-link-color-hover', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .navbar-nav > .nav-item:hover > .nav-link',
					'#main-menu .navbar-nav > .nav-item.active > .nav-link',
					'#main-menu .navbar-brand:hover',
				),
				'declarations' => array(
					'color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-main-menu-dropdown-background-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .dropdown-menu'
				),
				'declarations' => array(
					'background-color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-main-menu-dropdown-item-background-color-hover', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .dropdown-menu .dropdown-item:hover',
					'#main-menu .dropdown-menu .dropdown-item:focus',
				),
				'declarations' => array(
					'background-color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-main-menu-dropdown-link-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .dropdown-menu .dropdown-item'
				),
				'declarations' => array(
					'color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-main-menu-dropdown-link-color-hover', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .dropdown-menu .dropdown-item:hover',
				),
				'declarations' => array(
					'color' => $color
				)
			);
		});

        $this->render_selectors('affvc-header-main-menu-toggle-icon-color', function ($mod) {
            $color = sanitize_hex_color($mod);

            return array(
                'selectors'    => array(
                    '#main-menu .navbar-toggler .navbar-toggler-icon',
                ),
                'declarations' => array(
                    'background-color' => $color,
                )
            );
        });

        $this->render_selectors('affvc-header-main-menu-toggle-icon-color-hover', function ($mod) {
            $color = sanitize_hex_color($mod);

            return array(
                'selectors'    => array(
                    '#main-menu .navbar-toggler:hover .navbar-toggler-icon',
                ),
                'declarations' => array(
                    'background-color' => $color,
                )
            );
        });

		$this->render_selectors('affvc-header-main-menu-toggle-border-color', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .navbar-toggler',
				),
				'declarations' => array(
					'border-color' => $color
				)
			);
		});

		$this->render_selectors('affvc-header-main-menu-toggle-border-color-hover', function ($mod) {
			$color = sanitize_hex_color($mod);

			return array(
				'selectors'    => array(
					'#main-menu .navbar-toggler:hover',
				),
				'declarations' => array(
					'border-color' => $color
				)
			);
		});
	}

	/**
	 * @inheritdoc
	 * @since 0.6
	 */
	public function enqueue_scripts()
	{
		// Nothing to do here
	}
}

