<?php
namespace Affilivice\Design\Setup;

if(!defined('ABSPATH')) {
    exit('Not allowed to access pages directly.');
}

class Assets_Setup
{
    /**
     * Get the url to the public assets directory.
     *
     * @since 0.8
     * @return string
     */
    public static function get_public_url()
    {
        return \Affc_Affilivice_Theme::get_root_url() . '/assets/public/';
    }

    /**
     * Get the url to the vendor assets directory.
     *
     * @since 0.8
     * @return string
     */
    public static function get_vendor_url()
    {
        return \Affc_Affilivice_Theme::get_root_url() . '/assets/vendor/';
    }

    /**
     * Get the url to the customizer assets directory.
     *
     * @since 0.8
     * @return string
     */
    public static function get_customizer_url()
    {
        return \Affc_Affilivice_Theme::get_root_url() . '/assets/customizer/';
    }

    /**
     * Add the public styles for the front end.
     *
     * @hook wp_enqueue_scripts
     * @since 0.6
     */
    public function add_public_styles()
    {
        // Tether
        $tether_url = WP_DEBUG ? self::get_vendor_url() . 'tether/css/tether.css' : 'https://cdnjs.cloudflare.com/ajax/libs/tether/1.4.0/css/tether.min.css';
        wp_register_style('tether', $tether_url, array(), '1.4.0');

        // Font Awesome
        $font_awesome_url = WP_DEBUG ? self::get_vendor_url() . 'font-awesome/css/font-awesome.css' : 'https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css';
        wp_register_style('font-awesome', $font_awesome_url, array(), '4.7.0');

        // Bootstrap
        $bootstrap_url = WP_DEBUG ? self::get_vendor_url() . 'bootstrap/css/bootstrap.css' : 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-alpha.6/css/bootstrap.min.css';
        wp_register_style('bootstrap', $bootstrap_url, array('tether', 'font-awesome'), '4.0.0-alpha6');

        $bootstrap_map_url = WP_DEBUG ? self::get_vendor_url() . 'bootstrap/css/bootstrap.css' : 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-alpha.6/css/bootstrap.min.css';
        wp_register_style('bootstrap-map', $bootstrap_map_url, array('bootstrap'), '4.0.0-alpha6');

        // Slick
        $slick_url = WP_DEBUG ? self::get_vendor_url() . 'slick/css/slick.css' : 'https://cdn.jsdelivr.net/jquery.slick/1.6.0/slick.css';
        wp_register_style('slick',$slick_url, array(), '2.0');

        $slick_theme_url = WP_DEBUG ? self::get_vendor_url() . 'slick/css/slick-theme.css' : 'https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.6.0/slick-theme.min.css';
        wp_register_style('slick-theme', $slick_theme_url, array('slick'), '2.0');

        // Affc_Affilivice_Theme
        $affilivice_url = WP_DEBUG ? self::get_public_url() . 'dist/css/style.css' : self::get_public_url() . 'dist/css/style.min.css';
        wp_register_style('affilivice', $affilivice_url, array('bootstrap', 'slick-theme'), \Affc_Affilivice_Theme::VERSION);

        wp_enqueue_style('tether');
        wp_enqueue_style('font-awesome');
        wp_enqueue_style('bootstrap');
        wp_enqueue_style('slick');
        wp_enqueue_style('slick-theme');
        wp_enqueue_style('affilivice');
    }

    /**
     * Add the public scripts for the front end.
     *
     * @hook wp_enqueue_scripts
     * @since 0.6
     */
    public function add_public_scripts()
    {
        // Tether
        $tether_url = WP_DEBUG ? self::get_vendor_url() . 'tether/js/tether.js' : 'https://cdnjs.cloudflare.com/ajax/libs/tether/1.4.0/js/tether.min.js';
        wp_register_script('tether', $tether_url, array(), '1.4.0', true);

        // Bootstrap
        $bootstrap_url = WP_DEBUG ? self::get_vendor_url() . 'bootstrap/js/bootstrap.js' : 'https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0-alpha.6/js/bootstrap.min.js';
        wp_register_script('bootstrap', $bootstrap_url, array('jquery', 'tether'), '4.0.0-alpha6');

        // Slick
        $slick_url = WP_DEBUG ? self::get_vendor_url() . 'slick/js/slick.js' : 'https://cdn.jsdelivr.net/jquery.slick/1.6.0/slick.min.js';
        wp_register_script('slick', $slick_url, array('jquery'), '2.0.0', true);

        // Retina
        $retina_url = self::get_vendor_url() . 'retina/js/retina.min.js';
        wp_register_script('retina', $retina_url, array(), '2.1.0', true);

        // Affc_Affilivice_Theme
        $affilivice_url = WP_DEBUG ? self::get_public_url() . 'dist/js/script.js' : self::get_public_url() . 'dist/js/script.min.js';
        wp_register_script('affilivice', $affilivice_url, array('jquery', 'bootstrap', 'slick', 'retina'), \Affc_Affilivice_Theme::VERSION, true);
        wp_localize_script('affilivice', 'translations', array(
            'noMoreResults' => __('No more results available.', 'affilivice'),
        ));

        wp_enqueue_script('tether');
        wp_enqueue_script('bootstrap');
        wp_enqueue_script('slick');
        wp_enqueue_script('retina');
        wp_enqueue_script('affilivice');

        if (is_singular()) {
            wp_enqueue_script('comment-reply');
        }
    }

	/**
	 * Add the customizer scripts for the back end.
	 *
     * @hook customize_preview_init
	 * @since 0.6
	 */
    public function add_customizer_scripts()
    {
        // Customizer
        $customizer_url = WP_DEBUG ? self::get_customizer_url() . 'dist/js/customizer.js' : self::get_customizer_url() . 'dist/js/customizer.min.js';
	    wp_register_script('affilivice-customizer', $customizer_url, array('jquery','customize-preview'), time(), true);

        wp_enqueue_script('affilivice-customizer');
    }
}
